@@ -28,24 +28,13 @@ for simulating keyboard and mouse events.
 # pylint: disable=E0401
 # This file imports Win32-only symbols.
 
+import sys
 from ctypes import (c_short, c_long, c_ushort, c_ulong, sizeof,
                     POINTER, pointer, Structure, Union, windll)
+
 import win32con
 import win32api
 
-# These virtual keys don't have corresponding scancodes.
-# The list was found experimentally and is open to improvement.
-SOFT_KEYS = [x for x in range(0xc1, 0xdb)]
-SOFT_KEYS += [x for x in range(0x15, 0x1b)]
-SOFT_KEYS += [x for x in range(0x1c, 0x20)]
-SOFT_KEYS += [x for x in range(0x3a, 0x41)]
-SOFT_KEYS += [x for x in range(0x88, 0x90)]
-SOFT_KEYS += [x for x in range(0xa6, 0xba)]
-SOFT_KEYS += [
-    0xe0, 0xe5, 0xe7, 0xe8, 0xfc, 0x01, 0x02, 0x4, 0x5, 0x6, 0x7, 0x0a, 0x0b,
-    0x0e, 0x0f, 0x5d, 0x5e, 0x5f
-]
-
 
 class KeyboardInput(Structure):
     """Win32 KEYBDINPUT wrapper."""
@@ -55,9 +44,6 @@ class KeyboardInput(Structure):
                 ("dwFlags", c_ulong),
                 ("time", c_ulong),
                 ("dwExtraInfo", POINTER(c_ulong))]
-    soft_keys = set(SOFT_KEYS)
-
-    # pylint: disable=line-too-long
 
     #  From https://docs.microsoft.com/en-us/windows/desktop/inputdev/about-keyboard-input#extended-key-flag
     #     The extended keys consist of the ALT and CTRL keys
@@ -69,7 +55,7 @@ class KeyboardInput(Structure):
     #
     #  It's unclear if the Windows keys are also "extended", so they
     #  have been included for historical reasons.
-    extended_keys = set((
+    extended_keys = {
         win32con.VK_UP,
         win32con.VK_DOWN,
         win32con.VK_LEFT,
@@ -88,32 +74,56 @@ class KeyboardInput(Structure):
         win32con.VK_DIVIDE,
         win32con.VK_LWIN,
         win32con.VK_RWIN,
-    ))
+    }
+    soft_keys = {
+        win32con.VK_PAUSE,
+    }
 
-    def __init__(self, virtual_keycode, down, scancode=-1, layout=None):
+
+    def __init__(self, virtual_keycode, down, scancode=None, layout=None):
         """Initialize structure based on key type."""
-        if scancode == -1:
-            if not layout:
-                scancode = windll.user32.MapVirtualKeyW(virtual_keycode, 0)
-            else:
-                # Assume that 'layout' is a keyboard layout (HKL).
-                scancode = windll.user32.MapVirtualKeyExW(virtual_keycode,
-                                                          0, layout)
-
         flags = 0
         if virtual_keycode == 0:
             flags |= 4  # KEYEVENTF_UNICODE
         else:
-            if virtual_keycode not in self.soft_keys:
+            # Translate *virtual_keycode* into a scan code, if necessary.
+            #  Assume that *layout* is a keyboard layout (HKL).
+            if scancode is None:
+                user32 = windll.user32
+                if sys.getwindowsversion().major < 6:
+                    map_type = 0  # MAPVK_VK_TO_VSC
+                else:
+                    map_type = 4  # MAPVK_VK_TO_VSC_EX
+                if layout is None:
+                    scancode = user32.MapVirtualKeyW(virtual_keycode,
+                                                     map_type)
+                else:
+                    scancode = user32.MapVirtualKeyExW(virtual_keycode,
+                                                       map_type,
+                                                       layout)
+
+            # Add the KEYEVENTF_SCANCODE flag if the Win32 MapVirtualKey(Ex)
+            #  function returned a translation.  If not, then fallback on
+            #  the specified keycode.  This is also done for "soft" keys.
+            if scancode and virtual_keycode not in self.soft_keys:
                 flags |= 8  # KEYEVENTF_SCANCODE
+
+                # Add the KEYEVENTF_EXTENDEDKEY flag, if necessary.
+                #  Starting with Windows Vista, extended scan codes are
+                #  specified with the high byte containing either 0xe0 or
+                #  0xe1.
+                if scancode >> 8 in (0xe0, 0xe1):
+                    flags |= win32con.KEYEVENTF_EXTENDEDKEY
+
+            # Always add the KEYEVENTF_EXTENDEDKEY flag for certain
+            #  virtual-keys (see above).
             if virtual_keycode in self.extended_keys:
                 flags |= win32con.KEYEVENTF_EXTENDEDKEY
+
         if not down:
             flags |= win32con.KEYEVENTF_KEYUP
-        
 
         extra = pointer(c_ulong(0))
-        # print(virtual_keycode, scancode, flags, 0, extra)
         Structure.__init__(self, virtual_keycode, scancode, flags, 0, extra)
 
 
