@@ -30,7 +30,7 @@ from dragonfly import Window
 
 from .recobs import TextRecobsManager
 from ..base import (EngineBase, MimicFailure, ThreadedTimerManager,
-                    DictationContainerBase)
+                    DictationContainerBase, GrammarWrapperBase)
 
 
 def _map_word(word):
@@ -167,7 +167,24 @@ class TextInputEngine(EngineBase):
             pass
 
     def mimic(self, words, **kwargs):
-        """ Mimic a recognition of the given *words*. """
+        """
+        Mimic a recognition of the given *words*.
+
+        :param words: words to mimic
+        :type words: str|iter
+        :Keyword Arguments:
+
+           optional *executable*, *title* and/or *handle* keyword arguments
+           may be used to simulate a specific foreground window context. The
+           current foreground window attributes will be used instead for any
+           keyword arguments not present.
+
+        .. note::
+
+           Any dictation words should be all uppercase, e.g. "HELLO WORLD".
+           Dictation words not in uppercase will result in the engine
+           **not** decoding and recognizing the command!
+        """
         # Handle string input.
         if isinstance(words, string_types):
             words = words.split()
@@ -226,7 +243,7 @@ class TextInputEngine(EngineBase):
 
         # If no processing occurred, then the mimic failed.
         if not processing_occurred:
-            self._recognition_observer_manager.notify_failure()
+            self._recognition_observer_manager.notify_failure(None)
             raise MimicFailure("No matching rule found for words %r."
                                % (words,))
 
@@ -255,15 +272,16 @@ class TextInputEngine(EngineBase):
 
         self._language = value
 
+    def _has_quoted_words_support(self):
+        return False
 
-class GrammarWrapper(object):
+
+class GrammarWrapper(GrammarWrapperBase):
 
     _log = logging.getLogger("engine")
 
-    def __init__(self, grammar, engine, observer_manager):
-        self.grammar = grammar
-        self.engine = engine
-        self._observer_manager = observer_manager
+    def __init__(self, grammar, engine, recobs_manager):
+        GrammarWrapperBase.__init__(self, grammar, engine, recobs_manager)
         self.exclusive = False
 
     def process_begin(self, executable, title, handle):
@@ -277,29 +295,38 @@ class GrammarWrapper(object):
 
         self._log.debug("Grammar %s: received recognition %r."
                         % (self.grammar.name, words))
+
+        # TODO Make special grammar callbacks work properly.
+        # These special methods are never called for this engine.
+        results_obj = None
         if words == "other":
             func = getattr(self.grammar, "process_recognition_other", None)
-            if func:
-                func(words)
+            self._process_grammar_callback(func, words=words,
+                                           results=results_obj)
             return
         elif words == "reject":
-            func = getattr(self.grammar, "process_recognition_failure", None)
-            if func:
-                func()
+            func = getattr(self.grammar, "process_recognition_failure",
+                           None)
+            self._process_grammar_callback(func, results=results_obj)
             return
 
         # If the words argument was not "other" or "reject", then it is a
         # sequence of (word, rule_id) 2-tuples.
+        words_rules = tuple(words)
+        words = tuple(word for word, _ in words)
+
         # Call the grammar's general process_recognition method, if present.
         func = getattr(self.grammar, "process_recognition", None)
         if func:
-            if not func(words):
+            if not self._process_grammar_callback(func, words=words,
+                                                  results=results_obj):
+                # Return early if the method didn't return True or equiv.
                 return
 
         # Iterate through this grammar's rules, attempting to decode each.
         # If successful, call that rule's method for processing the
         # recognition and return.
-        s = state_.State(words, self.grammar.rule_names, self.engine)
+        s = state_.State(words_rules, self.grammar.rule_names, self.engine)
         for r in self.grammar.rules:
             if not (r.active and r.exported):
                 continue
@@ -309,19 +336,17 @@ class GrammarWrapper(object):
                     try:
                         root = s.build_parse_tree()
 
-                        # Notify observers using the manager *before* processing.
-                        self._observer_manager.notify_recognition(
-                            tuple([word for word, _ in words]),
-                            r,
-                            root
+                        # Notify observers using the manager *before*
+                        # processing.
+                        notify_args = (words, r, root, results_obj)
+                        self.recobs_manager.notify_recognition(
+                            *notify_args
                         )
 
                         r.process_recognition(root)
 
-                        self._observer_manager.notify_post_recognition(
-                            tuple([word for word, _ in words]),
-                            r,
-                            root
+                        self.recobs_manager.notify_post_recognition(
+                            *notify_args
                         )
                     except Exception as e:
                         self._log.exception("Failed to process rule "
